==> guilded.py-1.3.0.tar.gz: guilded.py-1.3.0/guilded/types/forum_topic.py <==
"""
MIT License

Copyright (c) 2020-present shay (shayypy)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import annotations
from typing import TypedDict
from typing_extensions import NotRequired

from .channel import Mentions


class ForumTopicSummary(TypedDict):
    id: int
    serverId: str
    channelId: str
    title: str
    createdAt: str
    createdBy: str
    createdByWebhookId: NotRequired[str]
    updatedAt: NotRequired[str]
    bumpedAt: NotRequired[str]


class ForumTopic(ForumTopicSummary):
    content: str
    mentions: NotRequired[Mentions]

==> guilded.py-1.6.0.tar.gz: guilded.py-1.6.0/guilded/types/forum_topic.py <==
"""
MIT License

Copyright (c) 2020-present shay (shayypy)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import annotations
from typing import Optional, TypedDict
from typing_extensions import NotRequired

from .channel import Mentions


class ForumTopicSummary(TypedDict):
    id: int
    serverId: str
    channelId: str
    title: str
    createdAt: str
    createdBy: str
    createdByWebhookId: NotRequired[str]
    updatedAt: NotRequired[str]
    bumpedAt: NotRequired[str]
    isPinned: NotRequired[bool]
    isLocked: NotRequired[bool]


class ForumTopic(ForumTopicSummary):
    content: str
    mentions: NotRequired[Mentions]


class ForumTopicComment(TypedDict):
    id: int
    content: str
    createdAt: str
    updatedAt: NotRequired[Optional[str]]
    forumTopicId: int
    channelId: str
    createdBy: str
